==> trend_etl-1.0.1.tar.gz: trend_etl-1.0.1/trend_etl/functions/index_test.py <==
import unittest
from unittest.mock import Mock

from pyspark.sql import SparkSession
from pyspark.testing import assertDataFrameEqual
from trend_etl.test_utils import getspark
from trend_etl.functions.index import merge_drop_duplicates
import trend_etl.schema.fields as fields


class TestFunctions(unittest.TestCase):
    spark: SparkSession

    @classmethod
    def setUpClass(cls) -> None:
        cls.spark = getspark()

    def test_merge_drop_dupes_noop(self) -> None:
        data = [("apple", 1, 42), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got1 = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        got2 = merge_drop_duplicates(df, "keep-newest", "fruit", "picked_on")
        assertDataFrameEqual(got1, df)
        assertDataFrameEqual(got2, df)

    def test_merge_drop_dupes_oldest(self) -> None:
        data = [("apple", 1, 42), ("apple", 2, 1337), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        data = [("apple", 1, 42), ("lemon", 1, 69)]
        want = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        assertDataFrameEqual(got, want)

    def test_merge_drop_dupes_newest(self) -> None:
        data = [("apple", 1, 42), ("apple", 2, 1337), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-newest", "fruit", "picked_on")
        data = [("apple", 2, 1337), ("lemon", 1, 69)]
        want = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        assertDataFrameEqual(got, want)

    def test_merge_drop_dupes_dupes(self) -> None:
        data = [("apple", 1, 42), ("apple", 1, 24), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        self.assertEqual(2, got.count(), "dataframe size different")

==> trend_etl-1.4.4.tar.gz: trend_etl-1.4.4/trend_etl/functions/index_test.py <==
import unittest
from unittest.mock import Mock

from pyspark.sql import SparkSession
from pyspark.sql.functions import col, format_string
from pyspark.testing import assertDataFrameEqual
from trend_etl.test_utils import getspark
from trend_etl.functions.index import merge_drop_duplicates, merge_drop_duplicates_key
import trend_etl.schema.fields as fields


class TestFunctions(unittest.TestCase):
    spark: SparkSession

    @classmethod
    def setUpClass(cls) -> None:
        cls.spark = getspark()

    def test_merge_drop_dupes_noop(self) -> None:
        data = [("apple", 1, 42), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got1 = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        got2 = merge_drop_duplicates(df, "keep-newest", "fruit", "picked_on")
        assertDataFrameEqual(got1, df)
        assertDataFrameEqual(got2, df)

    def test_merge_drop_dupes_oldest(self) -> None:
        data = [("apple", 1, 42), ("apple", 2, 1337), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        data = [("apple", 1, 42), ("lemon", 1, 69)]
        want = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        assertDataFrameEqual(got, want)

    def test_merge_drop_dupes_newest(self) -> None:
        data = [("apple", 1, 42), ("apple", 2, 1337), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-newest", "fruit", "picked_on")
        data = [("apple", 2, 1337), ("lemon", 1, 69)]
        want = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        assertDataFrameEqual(got, want)

    def test_merge_drop_dupes_dupes(self) -> None:
        data = [("apple", 1, 42), ("apple", 1, 24), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        self.assertEqual(2, got.count(), "dataframe size different")

    def test_merge_drop_dupes_key(self) -> None:
        data = [
            ("apple", ("red", "Sept"), (None, "👎")),
            ("apple", ("green", "Oct"), (None, "👍")),
            ("apple", ("green", "Oct"), (None, "👍")),
            ("apple", ("blue", "Jun"), (None, "🤨")),
        ]
        df = self.__class__.spark.createDataFrame(
            data,
            schema="fruit string, picked struct<color string, month string>, emoji struct<id string, name string>",
        )
        got = merge_drop_duplicates_key(
            df,
            format_string(
                "%s%s%s", col("fruit"), col("picked.color"), col("emoji.name")
            ),
        )
        self.assertEqual(len(data) - 1, got.count(), "dataframe size different")
